@@ -5,14 +5,19 @@ fn main() {
     capture_display().unwrap().save("screenshot.jpg").unwrap();
 
     // capture window by known id
-    capture_window(67136).unwrap().save("screenshot.jpg").unwrap();
+    capture_window(132266)
+        .unwrap()
+        .save("screenshot.jpg")
+        .unwrap();
 
     // capture window by Name
     let window_name = "WindowName";
 
     match find_window(window_name) {
         Ok(hwnd) => capture_window(hwnd)
-            .unwrap().save("screenshot.jpg").unwrap(),
-        Err(_) => panic!("window {} not found!", window_name)
+            .unwrap()
+            .save("screenshot.jpg")
+            .unwrap(),
+        Err(_) => panic!("window {} not found!", window_name),
     }
-}
\ No newline at end of file
+}
